/*! \file file_io.h
 *
 * C++ wrapper of FORTRAN I/O operations with files.
 */

/*! \brief Open a file for subsequent access.
 *
 * \param uid: `int*` Pointer to the unit ID to be associated to the file.
 * \param name: `char*` C-string for file name (max. length of 63).
 * \param sta: `char*` C-string for file status (max. length of 7).
 * \param mode: `char*` C-string for access mode (max. length of 11).
 */
extern "C" void open_file_(int*, const char*, const char*, const char*);
/*! \brief Close a previously opened file.
 *
 * \param uid: `int*` Pointer to the unit ID of the file.
 */
extern "C" void close_file_(int*);
/*! \brief Read an integer value from a file.
 *
 * \param uid: `int*` Pointer to the unit ID of the file.
 * \param value: `int*` Pointer of the variable to be updated.
 */
extern "C" void read_int_(int*, int*);
/*! \brief Write a complex value to a file.
 *
 * \param uid: `int*` Pointer to the unit ID of the file.
 * \param real: `double*` Pointer to the real part of the value.
 * \param imag: `double*` Pointer to the imaginary part of the value.
 */
extern "C" void write_complex_(int*, double*, double*);
/*! \brief Write a double precision float value to a file.
 *
 * \param uid: `int*` Pointer to the unit ID of the file.
 * \param value: `double*` Pointer to the variable to be written.
 */
extern "C" void write_double_(int*, double*);
/*! \brief Write an integer value to a file.
 *
 * \param uid: `int*` Pointer to the unit ID of the file.
 * \param value: `int*` Pointer to the variable to be written.
 */
extern "C" void write_int_(int*, int*);
